/*
 * PhoneGap is available under *either* the terms of the modified BSD license *or* the
 * MIT License (2008). See http://opensource.org/licenses/alphabetical for full text.
 *
 * Copyright 2012, Andrew Lunny, Adobe Systems
 * Copyright (c) 2005-2010, Nitobi Software Inc.
 * Copyright (c) 2011, IBM Corporation
 * (c) 2010 Jesse MacFadyen, Nitobi
 */

var ChildBrowser = (function (gap) {
	var ref;
	
    function isFunction(f) {
        return typeof f === "function";
    }

    // placeholder and constants
    function ChildBrowser() {}

    var CLOSE_EVENT = 0,
        LOCATION_CHANGED_EVENT = 1,
        OPEN_EXTERNAL_EVENT = 2;

    /**
     * Function called when the child browser has an event.
     */
    function onEvent(data) {
        switch (data.type) {
            case CLOSE_EVENT:
                if (isFunction(ChildBrowser.onClose)) {
                    ChildBrowser.onClose();
                }
                break;
            case LOCATION_CHANGED_EVENT:
                if (isFunction(ChildBrowser.onLocationChange)) {
                    ChildBrowser.onLocationChange(data.location);
                }
                break;
            case OPEN_EXTERNAL_EVENT:
                if (isFunction(ChildBrowser.onOpenExternal)) {
                    ChildBrowser.onOpenExternal();
                }
                break;
        }
    }

    /**
     * Function called when the child browser has an error.
     */
    function onError(data) {
        if (isFunction(ChildBrowser.onError)) {
            ChildBrowser.onError(data);
        }
    }

    /**
     * Maintain API consistency with iOS
     */
    ChildBrowser.install = function () {
        console.log('ChildBrowser.install is deprecated');
    }

    /**
     * Display a new browser with the specified URL.
     * This method loads up a new web view in a dialog.
     *
     * @param url           The url to load
     * @param options       An object that specifies additional options
     */
    ChildBrowser.showWebPage = function (url, options) {
        if (!options) {
            options = { showLocationBar: true };
        }
                    
        ref = window.open(url, "_blank", "enableViewportScale=yes,location=" + (options.showLocationBar && options.showAddress ? "yes" : "no") 
                + ",toolbar=" + (options.showNavigationBar ? "yes" : "no"));
        return ref;
    };

    /**
     * Close the browser opened by showWebPage.
     */
    ChildBrowser.close = function () {
    	ref.close();
    };

    /**
     * Display a new browser with the specified URL.
     * This method starts a new web browser activity.
     *
     * @param url           The url to load
     * @param usePhoneGap   Load url in PhoneGap webview [optional]
     */
    ChildBrowser.openExternal = function(url, usePhoneGap) {
    	return window.open(url, "_system");
    };

    if (!window.plugins) {
        window.plugins = {};
    }
    window.plugins.childBrowser = ChildBrowser;

    return ChildBrowser;
})(window.cordova || window.Cordova || window.PhoneGap);


//window.plugins.emailComposer

function EmailComposer() {
	this.resultCallback = null; // Function
}

EmailComposer.ComposeResultType = {
Cancelled:0,
Saved:1,
Sent:2,
Failed:3,
NotSent:4
}



// showEmailComposer : all args optional

EmailComposer.prototype.showEmailComposer = function(subject,body,toRecipients,ccRecipients,bccRecipients,bIsHTML) {
	var args = {};
	if(toRecipients)
		args.toRecipients = toRecipients;
	if(ccRecipients)
		args.ccRecipients = ccRecipients;
	if(bccRecipients)
		args.bccRecipients = bccRecipients;
	if(subject)
		args.subject = subject;
	if(body)
		args.body = body;
	if(bIsHTML)
		args.bIsHTML = bIsHTML;
	
	cordova.exec(null, null, "EmailComposer", "showEmailComposer", [args]);
}

// this will be forever known as the orch-func -jm
EmailComposer.prototype.showEmailComposerWithCB = function(cbFunction,subject,body,toRecipients,ccRecipients,bccRecipients,bIsHTML) {
	this.resultCallback = cbFunction;
	this.showEmailComposer.apply(this,[subject,body,toRecipients,ccRecipients,bccRecipients,bIsHTML]);
}

EmailComposer.prototype._didFinishWithResult = function(res) {
	this.resultCallback(res);
}



cordova.addConstructor(function()  {
					   if(!window.plugins)
					   {
					   window.plugins = {};
					   }
					   
					   // shim to work in 1.5 and 1.6
					   if (!window.Cordova) {
					   window.Cordova = cordova;
					   };
					   
					   window.plugins.emailComposer = new EmailComposer();
					   });